# Licensed under Apache License Version 2.0 - see LICENSE

"""Utilities based on Pythons iterators and generators."""

from _iteration_utilities import *

from ._utils import *
from ._recipes import *
from ._additional_recipes import *
from ._classes import *

__version__ = '0.7.0'
